log

package
v0.0.0-...-7b69fb9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 24, 2025 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Overview

Code generated by go-enum DO NOT EDIT.

Index

Constants

This section is empty.

Variables

var ErrInvalidFormatType = fmt.Errorf("not a valid FormatType, try [%s]", strings.Join(_FormatTypeNames, ", "))

Functions

func Configure

func Configure(cfg *Config)

Configure applies configuration to the global logger.

func ConfigureLogger

func ConfigureLogger(logger *logrus.Logger, cfg *Config)

Configure applies configuration to the given logger.

func CtxWithFields

func CtxWithFields(ctx context.Context, fields logrus.Fields) (context.Context, *logrus.Entry)

func EscapeInput

func EscapeInput(input string) string

EscapeInput removes line breaks from input

func FormatTypeNames

func FormatTypeNames() []string

FormatTypeNames returns a list of possible string values of FormatType.

func FromCtx

func FromCtx(ctx context.Context) *logrus.Entry

func Log

func Log() *logrus.Logger

Log returns the global logger

func NewCtx

func NewCtx(ctx context.Context, logger *logrus.Entry) (context.Context, *logrus.Entry)

func PrefixedLog

func PrefixedLog(prefix string) *logrus.Entry

PrefixedLog return the global logger with prefix

func Silence

func Silence()

Silence disables the logger output

func WithIndent

func WithIndent(log *logrus.Entry, prefix string, callback func(*logrus.Entry))

func WithPrefix

func WithPrefix(logger *logrus.Entry, prefix string) *logrus.Entry

WithPrefix adds the given prefix to the logger.

func WrapCtx

func WrapCtx(ctx context.Context, wrap func(*logrus.Entry) *logrus.Entry) (context.Context, *logrus.Entry)

Types

type Config

type Config struct {
	Level     logrus.Level `yaml:"level" default:"info"`
	Format    FormatType   `yaml:"format" default:"text"`
	Privacy   bool         `yaml:"privacy" default:"false"`
	Timestamp bool         `yaml:"timestamp" default:"true"`
}

Config defines all logging configurations

func DefaultConfig

func DefaultConfig() *Config

DefaultConfig returns a new Config initialized with default values.

type FormatType

type FormatType int

FormatType format for logging ENUM( text // logging as text json // JSON format )

const (
	// FormatTypeText is a FormatType of type Text.
	// logging as text
	FormatTypeText FormatType = iota
	// FormatTypeJson is a FormatType of type Json.
	// JSON format
	FormatTypeJson
)

func ParseFormatType

func ParseFormatType(name string) (FormatType, error)

ParseFormatType attempts to convert a string to a FormatType.

func (FormatType) IsValid

func (x FormatType) IsValid() bool

IsValid provides a quick way to determine if the typed value is part of the allowed enumerated values

func (FormatType) MarshalText

func (x FormatType) MarshalText() ([]byte, error)

MarshalText implements the text marshaller method.

func (FormatType) String

func (x FormatType) String() string

String implements the Stringer interface.

func (*FormatType) UnmarshalText

func (x *FormatType) UnmarshalText(text []byte) error

UnmarshalText implements the text unmarshaller method.

Jump to